//[mahjong-utils](../../index.md)/[mahjongutils.hora.helpers](index.md)

# Package-level declarations

## Functions

| Name | Summary |
|---|---|
| [calcHan](calc-han.md) | [common]<br>fun [calcHan](calc-han.md)(pattern: [HoraHandPattern](../mahjongutils.hora/-hora-hand-pattern/index.md), options: [HoraOptions](../mahjongutils.hora/-hora-options/index.md), yaku: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../mahjongutils.yaku/-yaku/index.md)&gt;, dora: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
